==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/GetTestResultVideoDownloadURLPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property packageName The resource name of the Test Base Package.
 * @property resourceGroupName The name of the resource group that contains the resource.
 * @property testBaseAccountName The resource name of the Test Base Account.
 * @property testResultName The Test Result Name. It equals to TestResult-{TestResultId} string.
 */
public data class GetTestResultVideoDownloadURLPlainArgs(
    public val packageName: String,
    public val resourceGroupName: String,
    public val testBaseAccountName: String,
    public val testResultName: String,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs =
        com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs.builder()
            .packageName(packageName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .testBaseAccountName(testBaseAccountName.let({ args0 -> args0 }))
            .testResultName(testResultName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTestResultVideoDownloadURLPlainArgs].
 */
@PulumiTagMarker
public class GetTestResultVideoDownloadURLPlainArgsBuilder internal constructor() {
    private var packageName: String? = null

    private var resourceGroupName: String? = null

    private var testBaseAccountName: String? = null

    private var testResultName: String? = null

    /**
     * @param value The resource name of the Test Base Package.
     */
    @JvmName("tiwbqfmglyhinotu")
    public suspend fun packageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packageName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource.
     */
    @JvmName("vafywhyveknfjyml")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The resource name of the Test Base Account.
     */
    @JvmName("bcwesubslidxrnvi")
    public suspend fun testBaseAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.testBaseAccountName = mapped
    }

    /**
     * @param value The Test Result Name. It equals to TestResult-{TestResultId} string.
     */
    @JvmName("qryuqfwbihyuattg")
    public suspend fun testResultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.testResultName = mapped
    }

    internal fun build(): GetTestResultVideoDownloadURLPlainArgs =
        GetTestResultVideoDownloadURLPlainArgs(
            packageName = packageName ?: throw PulumiNullFieldException("packageName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            testBaseAccountName = testBaseAccountName ?: throw PulumiNullFieldException("testBaseAccountName"),
            testResultName = testResultName ?: throw PulumiNullFieldException("testResultName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/inputs/GetTestResultVideoDownloadURLPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.inputs

import com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property packageName The resource name of the Test Base Package.
 * @property resourceGroupName The name of the resource group that contains the resource.
 * @property testBaseAccountName The resource name of the Test Base Account.
 * @property testResultName The Test Result Name. It equals to TestResult-{TestResultId} string.
 */
public data class GetTestResultVideoDownloadURLPlainArgs(
    public val packageName: String,
    public val resourceGroupName: String,
    public val testBaseAccountName: String,
    public val testResultName: String,
) : ConvertibleToJava<com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs =
        com.pulumi.azurenative.testbase.inputs.GetTestResultVideoDownloadURLPlainArgs.builder()
            .packageName(packageName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .testBaseAccountName(testBaseAccountName.let({ args0 -> args0 }))
            .testResultName(testResultName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetTestResultVideoDownloadURLPlainArgs].
 */
@PulumiTagMarker
public class GetTestResultVideoDownloadURLPlainArgsBuilder internal constructor() {
    private var packageName: String? = null

    private var resourceGroupName: String? = null

    private var testBaseAccountName: String? = null

    private var testResultName: String? = null

    /**
     * @param value The resource name of the Test Base Package.
     */
    @JvmName("kjjxumuybrgqqhqu")
    public suspend fun packageName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.packageName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource.
     */
    @JvmName("gittlnufrbayxucy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The resource name of the Test Base Account.
     */
    @JvmName("vihnmqmndccesqbq")
    public suspend fun testBaseAccountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.testBaseAccountName = mapped
    }

    /**
     * @param value The Test Result Name. It equals to TestResult-{TestResultId} string.
     */
    @JvmName("aydhywestvfrhflo")
    public suspend fun testResultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.testResultName = mapped
    }

    internal fun build(): GetTestResultVideoDownloadURLPlainArgs =
        GetTestResultVideoDownloadURLPlainArgs(
            packageName = packageName ?: throw PulumiNullFieldException("packageName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            testBaseAccountName = testBaseAccountName ?: throw PulumiNullFieldException("testBaseAccountName"),
            testResultName = testResultName ?: throw PulumiNullFieldException("testResultName"),
        )
}
